==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSAuthZImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlException;

import pl.edu.icm.unicore.uvos.api.AttributePermission;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.PermissionDesignator;
import pl.edu.icm.unicore.uvos.api.Permissions;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.api.UVOSAuthZInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSAuthZInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionXType;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionsListType;
import xmlbeans.pl.edu.icm.uvos.internal.GroupDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentitiesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentityDocument;
import xmlbeans.pl.edu.icm.uvos.internal.PermissionsDesignatorDocument;
import xmlbeans.pl.edu.icm.uvos.internal.PermissionsDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSAuthZInterface")
public class WSAuthZImpl implements WSAuthZInterface
{
	private static final Logger log = Logger.getLogger(WSAuthZImpl.class);
	private UVOSAuthZInterface voAuthz;
	private Authenticator authenticator;

	public WSAuthZImpl(UVOSAuthZInterface voAuthz, Authenticator auth) throws InternalException
	{
		this.voAuthz = voAuthz;
		this.authenticator = auth;
	}

	public PermissionsDocument checkPermissions(GroupDocument arg0, IdentityDocument arg1) 
	throws UVOSFault
	{
		try
		{
			log.debug("checkPermissions invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLPermissionsDoc(voAuthz.checkPermissions(
					XMLBeansMapper.map2APIGroup(arg0), 
					XMLBeansMapper.map2APIIdentity(arg1)));
		} catch (UVOSException e)
		{
			log.info("Error invoking checkPermissions: " + e);
			throw new UVOSFault(e);
		}
	}

	public AttributePermissionsListDocument getGroupAuthZ(GroupDocument arg0, boolean arg1)
	throws UVOSFault
	{
		try
		{
			log.debug("getGroupAuthZ invoked");
			authenticator.authenticate();

			List<AttributePermission> raw = voAuthz.getGroupAuthZ(
					XMLBeansMapper.map2APIGroup(arg0), arg1);

			AttributePermissionsListDocument retDoc = AttributePermissionsListDocument.
			Factory.newInstance();
			AttributePermissionsListType ret = retDoc.addNewAttributePermissionsList();
			AttributePermissionXType[] array = new AttributePermissionXType[raw.size()];
			for (int i=0; i<array.length; i++)
				array[i] = XMLBeansMapper.map2XMLAttrPerm(raw.get(i));
			ret.setElementArray(array);
			return retDoc;
		} catch (UVOSException e)
		{
			log.info("Error invoking getGroupAuthZ: " + e);
			throw new UVOSFault(e);
		}
	}

	public void modifyAuthenticationData(IdentityDocument arg0, String arg1) 
	throws UVOSFault
	{
		try
		{
			log.debug("modifyAuthenticationData invoked");
			authenticator.authenticate();
			Identity id = XMLBeansMapper.map2APIIdentity(arg0);
			voAuthz.modifyAuthenticationData(id, arg1);
			if (log.isDebugEnabled())
				log.debug("Modified authentication data of " + id.prettyString());
		} catch (UVOSException e)
		{
			log.info("Error invoking modifyAuthenticationData: " + e);
			throw new UVOSFault(e);
		}
	}

	public void modifyPermissions(GroupDocument arg0, PermissionsDesignatorDocument arg1,
			PermissionsDocument arg2) throws UVOSFault
			{
		try
		{
			log.debug("modifyPermissions invoked");
			authenticator.authenticate();
			Group g = XMLBeansMapper.map2APIGroup(arg0);
			PermissionDesignator pd = XMLBeansMapper.map2APIDesignator(
				arg1.getPermissionsDesignator());
			Permissions perm = XMLBeansMapper.map2APIPermissions(arg2.getPermissions());
			voAuthz.modifyPermissions(g, pd, perm);
			if (log.isDebugEnabled())
				log.debug("Modified group " + g + " permissions; designator " + pd
					+ " permissions set to " + perm);
		} catch (UVOSException e)
		{
			log.info("Error invoking modifyPermissions: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking modifyPermissions: " + e.getMessage());
			throw new UVOSFault(new InvalidValueException(e.getMessage()));
		}
	}

	public IdentitiesListDocument getMyIdentities() throws UVOSFault
	{
		try
		{
			log.debug("getMyIdentities invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLIdentitiesList(voAuthz.getMyIdentities());
		} catch (UVOSException e)
		{
			log.info("Error invoking getMyIdentities: " + e);
			throw new UVOSFault(e);
		}
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSAuthZImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlException;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.AttributePermission;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.PermissionDesignator;
import pl.edu.icm.unicore.uvos.api.Permissions;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.api.UVOSAuthZInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSAuthZInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionXType;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.AttributePermissionsListType;
import xmlbeans.pl.edu.icm.uvos.internal.GroupDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentitiesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentityDocument;
import xmlbeans.pl.edu.icm.uvos.internal.PermissionsDesignatorDocument;
import xmlbeans.pl.edu.icm.uvos.internal.PermissionsDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSAuthZInterface")
public class WSAuthZImpl implements WSAuthZInterface
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, WSAuthZImpl.class);
	private UVOSAuthZInterface voAuthz;
	private Authenticator authenticator;

	public WSAuthZImpl(UVOSAuthZInterface voAuthz, Authenticator auth) throws InternalException
	{
		this.voAuthz = voAuthz;
		this.authenticator = auth;
	}

	public PermissionsDocument checkPermissions(GroupDocument arg0, IdentityDocument arg1) 
	throws UVOSFault
	{
		try
		{
			log.debug("checkPermissions invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLPermissionsDoc(voAuthz.checkPermissions(
					XMLBeansMapper.map2APIGroup(arg0), 
					XMLBeansMapper.map2APIIdentity(arg1)));
		} catch (UVOSException e)
		{
			log.info("Error invoking checkPermissions: " + e);
			throw new UVOSFault(e);
		}
	}

	public AttributePermissionsListDocument getGroupAuthZ(GroupDocument arg0, boolean arg1)
	throws UVOSFault
	{
		try
		{
			log.debug("getGroupAuthZ invoked");
			authenticator.authenticate();

			List<AttributePermission> raw = voAuthz.getGroupAuthZ(
					XMLBeansMapper.map2APIGroup(arg0), arg1);

			AttributePermissionsListDocument retDoc = AttributePermissionsListDocument.
			Factory.newInstance();
			AttributePermissionsListType ret = retDoc.addNewAttributePermissionsList();
			AttributePermissionXType[] array = new AttributePermissionXType[raw.size()];
			for (int i=0; i<array.length; i++)
				array[i] = XMLBeansMapper.map2XMLAttrPerm(raw.get(i));
			ret.setElementArray(array);
			return retDoc;
		} catch (UVOSException e)
		{
			log.info("Error invoking getGroupAuthZ: " + e);
			throw new UVOSFault(e);
		}
	}

	public void modifyAuthenticationData(IdentityDocument arg0, String arg1) 
	throws UVOSFault
	{
		try
		{
			log.debug("modifyAuthenticationData invoked");
			authenticator.authenticate();
			Identity id = XMLBeansMapper.map2APIIdentity(arg0);
			voAuthz.modifyAuthenticationData(id, arg1);
			if (log.isDebugEnabled())
				log.debug("Modified authentication data of " + id.prettyString());
		} catch (UVOSException e)
		{
			log.info("Error invoking modifyAuthenticationData: " + e);
			throw new UVOSFault(e);
		}
	}

	public void modifyPermissions(GroupDocument arg0, PermissionsDesignatorDocument arg1,
			PermissionsDocument arg2) throws UVOSFault
			{
		try
		{
			log.debug("modifyPermissions invoked");
			authenticator.authenticate();
			Group g = XMLBeansMapper.map2APIGroup(arg0);
			PermissionDesignator pd = XMLBeansMapper.map2APIDesignator(
				arg1.getPermissionsDesignator());
			Permissions perm = XMLBeansMapper.map2APIPermissions(arg2.getPermissions());
			voAuthz.modifyPermissions(g, pd, perm);
			if (log.isDebugEnabled())
				log.debug("Modified group " + g + " permissions; designator " + pd
					+ " permissions set to " + perm);
		} catch (UVOSException e)
		{
			log.info("Error invoking modifyPermissions: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking modifyPermissions: " + e.getMessage());
			throw new UVOSFault(new InvalidValueException(e.getMessage()));
		}
	}

	public IdentitiesListDocument getMyIdentities() throws UVOSFault
	{
		try
		{
			log.debug("getMyIdentities invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLIdentitiesList(voAuthz.getMyIdentities());
		} catch (UVOSException e)
		{
			log.info("Error invoking getMyIdentities: " + e);
			throw new UVOSFault(e);
		}
	}
}
